@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #    OpaL Perl Modules
-#    Copyright (C) 2000,2007  Ola Lundqvist <ola@opalsys.net>
-#    $Id: read.pm 2527 2007-12-06 19:57:04Z ola $
+#    Copyright (C) 2000,2007-2008  Ola Lundqvist <ola@inguza.com>
+#
 #    For full COPYRIGHT notice see the COPYING document.
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 #
 #
 #    For more information take a look at the official homepage at:
-#      http://opalsys.net/software/opalmod
+#      http://inguza.com/software/opalmod
 #    or contact the author at:
-#      ola@opalsys.net
+#      ola@inguza.com
 #
 
 package OpaL::read;
@@ -149,7 +149,7 @@ USAGE:
 
 =head1 AUTHOR
 
-Ola Lundqvist <ola@opalsys.net>
+Ola Lundqvist <ola@inguza.com>
 
 =head1 SEE ALSO
 
@@ -166,7 +166,7 @@ perl(1).
 # Description:	Executes a program and read the piped result.
 # Returns:	Array of lines.
 # Arguments:	$command_string
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 #		2000-06-27	Better argument definition.
 ###############################################################################
@@ -183,7 +183,7 @@ sub readcommand {#($) {
 # Description:	Reads a file.
 # Returns:	Array of lines.
 # Arguments:	$filename
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-13
 #		2000-06-25	Removed &action from open. Not working.
 #		2000-06-27	Better argument definition.
@@ -202,7 +202,7 @@ sub readfile {#($) {
 # Description:	Reads a file.
 # Returns:	The first line.
 # Arguments:	$filename
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-13
 #		2000-07-06	Removed &action from open. Not working.
 #				Better argument definition.
@@ -221,7 +221,7 @@ sub readfileline { #($){
 # Description:	Reads a file.
 # Returns:	Entire file in scalar.
 # Arguments:	$filename
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-13
 #		2000-06-25	Removed &action from open. Not working.
 #		2000-06-27	Better argument definition.
@@ -243,7 +243,7 @@ sub readscalarfile {#($) {
 # Description:	Reads a command output into a scalar.
 # Returns:	Entire file in scalar.
 # Arguments:	$command
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-06-27	Wrote it.
 ###############################################################################
 sub readscalarcommand {#($) {
@@ -262,7 +262,7 @@ sub readscalarcommand {#($) {
 # Description:	Executes a program and read the piped result.
 # Returns:	The first line.
 # Arguments:	$command_string
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-01
 #		2000-06-27	Better argument definition.
 ###############################################################################
